@@ -13,10 +13,10 @@ def transcription(audio_path):
 	# load audio
 	speech, rate = librosa.load(audio_path,sr=16000)
 
-	input_values = my_processor(speech, sampling_rate=16_000, return_tensors="pt", padding=True).input_values
+	inputs = my_processor(speech, sampling_rate=16_000, return_tensors="pt", padding=True)
 
 	with torch.no_grad():
-  		logits = my_model(input_values, attention_mask=inputs.attention_mask).logits
+  		logits = my_model(inputs.input_values, attention_mask=inputs.attention_mask).logits
 
 	pred = my_processor.batch_decode(logits.numpy()).text
 	
